@@ -44,7 +44,7 @@ BEGIN
         '^'     => sub{ &_op_overload( @_, '^' ) },
         '|'     => sub{ &_op_overload( @_, '|' ) },
         '=='    => sub{ &_op_overload( @_, '=' ) },
-        'eq'    => sub{ &_op_overload( @_, '=' ) },
+        'eq'    => sub{ &_op_overload( @_, 'IS' ) },
         # Full Text Search operator
         '~~'    => sub{ &_op_overload( @_, '@@' ) },
         fallback => 1,
@@ -227,7 +227,7 @@ sub _op_overload
     '==' => '=',
     };
     $op = $map->{ $op } if( exists( $map->{ $op } ) );
-    $op = 'IS' if( $op eq '=' and $val eq 'NULL' );
+    # $op = 'IS' if( $op eq '=' and $val eq 'NULL' );
     # If the value specified in the operation is a placeholder, or a field object or a statement object, we do not want to quote process it
     unless( $val eq '?' || 
             ( $self->_is_object( $val ) && 
@@ -562,9 +562,13 @@ Another example, which works in PostgreSQL:
     $ip_tbl->where( 'inet 192.16.1.20' << $ip_tbl->fo->ip_addr );
     my $ref = $ip_tbl->select->fetchrow_hashref;
 
-The equal operator C<==> would become C<IS>:
+The equal operator C<==> would become C<=>:
 
-    $f == 'NULL' # dummy IS NULL
+    $f == 'NULL' # dummy = NULL
+
+but, if you use perl's C<eq> instead of C<==>, you would get:
+
+    $f eq 'NULL' # dummy IS NULL
 
 Note that you have to take care of quotes yourself, because there is no way to tell if the right hand side is a string or a function
 
@@ -572,8 +576,10 @@ Note that you have to take care of quotes yourself, because there is no way to t
 
 or, to insert a placeholder
 
-    $f == '?' # dummy IS ?
-    my $sth = $table->select( $f == '?' ); # SELECT dummy IS ? FROM some_table
+    $f == '?' # dummy = ?
+    # or;
+    $f eq '?' # dummy IS ?
+    my $sth = $table->select( $f eq '?' ); # SELECT dummy IS ? FROM some_table
     my $row = $sth->exec( 'JPY' )->fetchrow;
 
 of course
